@@ -1,6 +1,7 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2006, 2007 Ulyanov Igor <iulyanov@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2006-2007 Igor Ulyanov <iulyanov@gmail.com>
+ * Copyright (c) 2007-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,41 +17,45 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include <QResizeEvent>
+#include <QCoreApplication>
+#include <QPalette>
+
 #include "frameTeam.h"
 #include "teamselhelper.h"
 #include "hwconsts.h"
 
-#include <QResizeEvent>
-#include <QCoreApplication>
-
 FrameTeams::FrameTeams(QWidget* parent) :
-  QWidget(parent), maxHedgehogsPerGame(18), overallHedgehogs(0), mainLayout(this), nonInteractive(false)
+  QFrame(parent), maxHedgehogsPerGame(48), overallHedgehogs(0), mainLayout(this), nonInteractive(false)
 {
-  mainLayout.setSpacing(1);
+    QPalette newPalette = palette();
+    newPalette.setColor(QPalette::Window, QColor(0x00, 0x00, 0x00));
+    setPalette(newPalette);
+    setAutoFillBackground(true);
 
-  availableColors.push_back(*color1);
-  availableColors.push_back(*color2);
-  availableColors.push_back(*color3);
-  availableColors.push_back(*color4);
-  availableColors.push_back(*color5);
-  availableColors.push_back(*color6);
+    mainLayout.setSpacing(1);
+    mainLayout.setContentsMargins(4, 4, 4, 4);
 
-  resetColors();
+    int i = 0;
+    while(colors[i] != 0)
+        availableColors.push_back(QColor(colors[i++]));
+
+    resetColors();
 }
 
-void FrameTeams::setNonInteractive()
+void FrameTeams::setInteractivity(bool interactive)
 {
-  nonInteractive=true;
-  for(tmapTeamToWidget::iterator it=teamToWidget.begin(); it!=teamToWidget.end(); ++it) {
-    TeamShowWidget* pts=dynamic_cast<TeamShowWidget*>(it.value());
-    if(!pts) throw;
-    pts->setNonInteractive();
-  }
+    nonInteractive = !interactive;
+    for(tmapTeamToWidget::iterator it=teamToWidget.begin(); it!=teamToWidget.end(); ++it) {
+        TeamShowWidget* pts = dynamic_cast<TeamShowWidget*>(it.value());
+        if(!pts) throw;
+        pts->setInteractivity(interactive);
+    }
 }
 
 void FrameTeams::resetColors()
 {
-  currentColor=availableColors.begin();
+  currentColor=availableColors.end() - 1; // ensure next color is the first one
 }
 
 QColor FrameTeams::getNextColor() const
@@ -64,7 +69,7 @@ QColor FrameTeams::getNextColor() const
 void FrameTeams::addTeam(HWTeam team, bool willPlay)
 {
   TeamShowWidget* pTeamShowWidget = new TeamShowWidget(team, willPlay, this);
-  if(nonInteractive) pTeamShowWidget->setNonInteractive();
+  if(nonInteractive) pTeamShowWidget->setInteractivity(false);
 //  int hght=teamToWidget.empty() ? 0 : teamToWidget.begin()->second->size().height();
   mainLayout.addWidget(pTeamShowWidget);
   teamToWidget.insert(team, pTeamShowWidget);
@@ -77,7 +82,7 @@ void FrameTeams::removeTeam(HWTeam team)
   tmapTeamToWidget::iterator it=teamToWidget.find(team);
   if(it==teamToWidget.end()) return;
   mainLayout.removeWidget(it.value());
-  delete it.value();
+  it.value()->deleteLater();
   teamToWidget.erase(it);
 }
 
@@ -85,7 +90,7 @@ void FrameTeams::resetTeams()
 {
   for(tmapTeamToWidget::iterator it=teamToWidget.begin(); it!=teamToWidget.end(); ) {
     mainLayout.removeWidget(it.value());
-    delete it.value();
+    it.value()->deleteLater();
     teamToWidget.erase(it++);
   }
 }
@@ -106,6 +111,7 @@ void FrameTeams::setTeamColor(const HWTeam& team)
 
 QWidget* FrameTeams::getTeamWidget(HWTeam team)
 {
+//qDebug() << "FrameTeams::getTeamWidget getNetID() = " << team.getNetID();
   tmapTeamToWidget::iterator it=teamToWidget.find(team);
   QWidget* ret = it!=teamToWidget.end() ? it.value() : 0;
   return ret;
