@@ -1,6 +1,6 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2005-2010 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2005-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,8 @@ enum GameState {
     gsInterrupted = 2,
     gsFinished = 3,
     gsStopped = 4,
-    gsDestroyed = 5
+    gsDestroyed = 5,
+    gsHalted = 6
 };
 
 bool checkForDir(const QString & dir);
@@ -47,7 +48,7 @@ public:
     HWGame(GameUIConfig * config, GameCFGWidget * gamecfg, QString ammo, TeamSelWidget* pTeamSelWidget = 0);
     virtual ~HWGame();
     void AddTeam(const QString & team);
-    void PlayDemo(const QString & demofilename);
+    void PlayDemo(const QString & demofilename, bool isSave);
     void StartLocal();
     void StartQuick();
     void StartNet();
@@ -58,7 +59,7 @@ public:
     bool netSuspend;
 
  protected:
-    virtual QStringList setArguments();
+    virtual QStringList getArguments();
     virtual void onClientRead();
     virtual void onClientDisconnect();
 
@@ -83,6 +84,7 @@ private:
         gtNet      = 4,
         gtTraining = 5,
         gtCampaign = 6,
+        gtSave     = 7,
     };
     char msgbuf[MAXMSGCHARS];
     QString teams[5];
