@@ -1,6 +1,6 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2006-2010 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2006-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,9 @@
 #include "proto.h"
 
 GameCFGWidget::GameCFGWidget(QWidget* parent) :
-  QGroupBox(parent), mainLayout(this)
+  QGroupBox(parent)
+  , mainLayout(this)
+  , seedRegexp("\\{[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\\}")
 {
     mainLayout.setMargin(0);
 //  mainLayout.setSizeConstraint(QLayout::SetMinimumSize);
@@ -47,10 +49,11 @@ GameCFGWidget::GameCFGWidget(QWidget* parent) :
 
     QGridLayout *GBoxOptionsLayout = new QGridLayout(GBoxOptions);
 
-    GBoxOptionsLayout->addWidget(new QLabel(QLabel::tr("Gameplay"), GBoxOptions), 0, 0);
+    GBoxOptions->setTitle(tr("Game Options"));
+    GBoxOptionsLayout->addWidget(new QLabel(QLabel::tr("Style"), GBoxOptions), 1, 0);
 
     Scripts = new QComboBox(GBoxOptions);
-    GBoxOptionsLayout->addWidget(Scripts, 0, 1);
+    GBoxOptionsLayout->addWidget(Scripts, 1, 1);
 
     Scripts->addItem("Normal");
     Scripts->insertSeparator(1);
@@ -59,7 +62,9 @@ GameCFGWidget::GameCFGWidget(QWidget* parent) :
         QString script = (*scriptList)[i].remove(".lua", Qt::CaseInsensitive);
         QList<QVariant> scriptInfo;
         scriptInfo.push_back(script);
-        QFile scriptCfgFile(QString("%1/Scripts/Multiplayer/%2.cfg").arg(datadir->absolutePath()).arg(script));
+        QFile scriptCfgFile;
+        scriptCfgFile.setFileName(QString("%1/Data/Scripts/Multiplayer/%2.cfg").arg(cfgdir->absolutePath()).arg(script));
+        if (!scriptCfgFile.exists()) scriptCfgFile.setFileName(QString("%1/Scripts/Multiplayer/%2.cfg").arg(datadir->absolutePath()).arg(script));
         if (scriptCfgFile.exists() && scriptCfgFile.open(QFile::ReadOnly)) {
             QString scheme;
             QString weapons;
@@ -87,7 +92,7 @@ GameCFGWidget::GameCFGWidget(QWidget* parent) :
     connect(Scripts, SIGNAL(currentIndexChanged(int)), this, SLOT(scriptChanged(int)));
 
     QWidget *SchemeWidget = new QWidget(GBoxOptions);
-    GBoxOptionsLayout->addWidget(SchemeWidget, 1, 0, 1, 2);
+    GBoxOptionsLayout->addWidget(SchemeWidget, 2, 0, 1, 2);
 
     QGridLayout *SchemeWidgetLayout = new QGridLayout(SchemeWidget);
     SchemeWidgetLayout->setMargin(0);
@@ -96,7 +101,7 @@ GameCFGWidget::GameCFGWidget(QWidget* parent) :
     SchemeWidgetLayout->addWidget(GameSchemes, 0, 2);
     connect(GameSchemes, SIGNAL(currentIndexChanged(int)), this, SLOT(schemeChanged(int)));
 
-    SchemeWidgetLayout->addWidget(new QLabel(QLabel::tr("Game scheme"), SchemeWidget), 0, 0);
+    SchemeWidgetLayout->addWidget(new QLabel(QLabel::tr("Scheme"), SchemeWidget), 0, 0);
 
     QPixmap pmEdit(":/res/edit.png");
     
@@ -123,8 +128,6 @@ GameCFGWidget::GameCFGWidget(QWidget* parent) :
     SchemeWidgetLayout->addWidget(goToWeaponPage, 1, 3);
     connect(goToWeaponPage, SIGNAL(clicked()), this, SLOT(jumpToWeapons()));
 
-    //GBoxOptionsLayout->addWidget(new QLabel(QLabel::tr("Bind schemes with weapons"), GBoxOptions), 2, 0);
-
     bindEntries = new QCheckBox(SchemeWidget);
     bindEntries->setToolTip(tr("When this option is enabled selecting a game scheme will auto-select a weapon"));
     bindEntries->setChecked(true);
@@ -132,12 +135,11 @@ GameCFGWidget::GameCFGWidget(QWidget* parent) :
     bindEntries->setStyleSheet( "QCheckBox::indicator:checked   { image: url(\":/res/lock.png\"); }"
                                 "QCheckBox::indicator:unchecked { image: url(\":/res/unlock.png\");   }" );
     SchemeWidgetLayout->addWidget(bindEntries, 0, 1, 0, 1, Qt::AlignVCenter);
-    //GBoxOptionsLayout->addWidget(bindEntries, 2, 2);
 
     connect(pMapContainer, SIGNAL(seedChanged(const QString &)), this, SLOT(seedChanged(const QString &)));
     connect(pMapContainer, SIGNAL(mapChanged(const QString &)), this, SLOT(mapChanged(const QString &)));
     connect(pMapContainer, SIGNAL(mapgenChanged(MapGenerator)), this, SLOT(mapgenChanged(MapGenerator)));
-    connect(pMapContainer, SIGNAL(maze_sizeChanged(int)), this, SLOT(maze_sizeChanged(int)));
+    connect(pMapContainer, SIGNAL(mazeSizeChanged(int)), this, SLOT(maze_sizeChanged(int)));
     connect(pMapContainer, SIGNAL(themeChanged(const QString &)), this, SLOT(themeChanged(const QString &)));
     connect(pMapContainer, SIGNAL(newTemplateFilter(int)), this, SLOT(templateFilterChanged(int)));
     connect(pMapContainer, SIGNAL(drawMapRequested()), this, SIGNAL(goToDrawMap()));
@@ -209,13 +211,17 @@ quint32 GameCFGWidget::getGameFlags() const
         result |= 0x00800000;       // no wind
     if (schemeData(23).toBool())
         result |= 0x01000000;       // more wind
+    if (schemeData(24).toBool())
+        result |= 0x02000000;       // tag team
+    if (schemeData(25).toBool())
+        result |= 0x04000000;       // bottom border
 
     return result;
 }
 
 quint32 GameCFGWidget::getInitHealth() const
 {
-    return schemeData(26).toInt();
+    return schemeData(28).toInt();
 }
 
 QByteArray GameCFGWidget::getFullConfig() const
@@ -223,28 +229,43 @@ QByteArray GameCFGWidget::getFullConfig() const
     QList<QByteArray> bcfg;
     int mapgen = pMapContainer->get_mapgen();
 
+    QString currentMap = pMapContainer->getCurrentMap();
+    if (currentMap.size() > 0)
+    {
+        bcfg << QString("emap " + currentMap).toUtf8();
+        if(pMapContainer->getCurrentIsMission())
+            bcfg << QString("escript Maps/%1/map.lua").arg(currentMap).toUtf8();
+    }
+    bcfg << QString("etheme " + pMapContainer->getCurrentTheme()).toUtf8();
+
+    if (Scripts->currentIndex() > 0)
+    {
+        bcfg << QString("escript Scripts/Multiplayer/%1.lua").arg(Scripts->itemData(Scripts->currentIndex()).toList()[0].toString()).toUtf8();
+    }
+
     bcfg << QString("eseed " + pMapContainer->getCurrentSeed()).toUtf8();
     bcfg << QString("e$gmflags %1").arg(getGameFlags()).toUtf8();
-    bcfg << QString("e$damagepct %1").arg(schemeData(24).toInt()).toUtf8();
-    bcfg << QString("e$turntime %1").arg(schemeData(25).toInt() * 1000).toUtf8();
-    bcfg << QString("e$sd_turns %1").arg(schemeData(27).toInt()).toUtf8();
-    bcfg << QString("e$casefreq %1").arg(schemeData(28).toInt()).toUtf8();
-    bcfg << QString("e$minestime %1").arg(schemeData(29).toInt() * 1000).toUtf8();
-    bcfg << QString("e$minesnum %1").arg(schemeData(30).toInt()).toUtf8();
-    bcfg << QString("e$minedudpct %1").arg(schemeData(31).toInt()).toUtf8();
-    bcfg << QString("e$explosives %1").arg(schemeData(32).toInt()).toUtf8();
-    bcfg << QString("e$healthprob %1").arg(schemeData(33).toInt()).toUtf8();
-    bcfg << QString("e$hcaseamount %1").arg(schemeData(34).toInt()).toUtf8();
-    bcfg << QString("e$waterrise %1").arg(schemeData(35).toInt()).toUtf8();
-    bcfg << QString("e$healthdec %1").arg(schemeData(36).toInt()).toUtf8();
-    bcfg << QString("e$ropepct %1").arg(schemeData(37).toInt()).toUtf8();
+    bcfg << QString("e$damagepct %1").arg(schemeData(26).toInt()).toUtf8();
+    bcfg << QString("e$turntime %1").arg(schemeData(27).toInt() * 1000).toUtf8();
+    bcfg << QString("e$sd_turns %1").arg(schemeData(29).toInt()).toUtf8();
+    bcfg << QString("e$casefreq %1").arg(schemeData(30).toInt()).toUtf8();
+    bcfg << QString("e$minestime %1").arg(schemeData(31).toInt() * 1000).toUtf8();
+    bcfg << QString("e$minesnum %1").arg(schemeData(32).toInt()).toUtf8();
+    bcfg << QString("e$minedudpct %1").arg(schemeData(33).toInt()).toUtf8();
+    bcfg << QString("e$explosives %1").arg(schemeData(34).toInt()).toUtf8();
+    bcfg << QString("e$healthprob %1").arg(schemeData(35).toInt()).toUtf8();
+    bcfg << QString("e$hcaseamount %1").arg(schemeData(36).toInt()).toUtf8();
+    bcfg << QString("e$waterrise %1").arg(schemeData(37).toInt()).toUtf8();
+    bcfg << QString("e$healthdec %1").arg(schemeData(38).toInt()).toUtf8();
+    bcfg << QString("e$ropepct %1").arg(schemeData(39).toInt()).toUtf8();
+    bcfg << QString("e$getawaytime %1").arg(schemeData(40).toInt()).toUtf8();
     bcfg << QString("e$template_filter %1").arg(pMapContainer->getTemplateFilter()).toUtf8();
     bcfg << QString("e$mapgen %1").arg(mapgen).toUtf8();
 
     switch (mapgen)
     {
         case MAPGEN_MAZE:
-            bcfg << QString("e$maze_size %1").arg(pMapContainer->get_maze_size()).toUtf8();
+            bcfg << QString("e$maze_size %1").arg(pMapContainer->getMazeSize()).toUtf8();
             break;
 
         case MAPGEN_DRAWN:
@@ -263,20 +284,6 @@ QByteArray GameCFGWidget::getFullConfig() const
         default: ;
     }
 
-    QString currentMap = pMapContainer->getCurrentMap();
-    if (currentMap.size() > 0)
-    {
-        bcfg << QString("emap " + currentMap).toUtf8();
-        if(pMapContainer->getCurrentIsMission())
-            bcfg << QString("escript Maps/%1/map.lua").arg(currentMap).toUtf8();
-    }
-    bcfg << QString("etheme " + pMapContainer->getCurrentTheme()).toUtf8();
-
-    if (Scripts->currentIndex() > 0)
-    {
-        bcfg << QString("escript Scripts/Multiplayer/%1.lua").arg(Scripts->itemData(Scripts->currentIndex()).toList()[0].toString()).toUtf8();
-    }
-
     QByteArray result;
 
     foreach(QByteArray ba, bcfg)
@@ -313,7 +320,7 @@ void GameCFGWidget::fullNetConfig()
     scriptChanged(Scripts->currentIndex());
 
     mapgenChanged(pMapContainer->get_mapgen());
-    maze_sizeChanged(pMapContainer->get_maze_size());
+    maze_sizeChanged(pMapContainer->getMazeSize());
 
     // map must be the last
     QString map = pMapContainer->getCurrentMap();
@@ -332,7 +339,7 @@ void GameCFGWidget::setParam(const QString & param, const QStringList & slValue)
         }
         if (param == "SEED") {
             pMapContainer->setSeed(value);
-            if (!QRegExp("\\{[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\\}").exactMatch(value)) {
+            if (!seedRegexp.exactMatch(value)) {
                 pMapContainer->seedEdit->setVisible(true);
                 }
             return;
@@ -350,7 +357,7 @@ void GameCFGWidget::setParam(const QString & param, const QStringList & slValue)
             return;
         }
         if (param == "MAZE_SIZE") {
-            pMapContainer->setMaze_size(value.toUInt());
+            pMapContainer->setMazeSize(value.toUInt());
             return;
         }
         if (param == "SCRIPT") {
@@ -371,6 +378,25 @@ void GameCFGWidget::setParam(const QString & param, const QStringList & slValue)
         }
     }
 
+    if (slValue.size() == 5)
+    {
+        if (param == "FULLMAPCONFIG")
+        {
+            QString seed = slValue[3];
+            if (!seedRegexp.exactMatch(seed))
+                pMapContainer->seedEdit->setVisible(true);
+
+            pMapContainer->setAllMapParameters(
+                    slValue[0],
+                    (MapGenerator)slValue[1].toUInt(),
+                    slValue[2].toUInt(),
+                    seed,
+                    slValue[4].toUInt()
+                    );
+            return;
+        }
+    }
+
     qWarning("Got bad config param from net");
 }
 
