@@ -1,6 +1,6 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2006-2008 Igor Ulyanov <iulyanov@gmail.com>
+ * Copyright (c) 2006-2011 Igor Ulyanov <iulyanov@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,17 +24,18 @@
 #include <QLinearGradient>
 #include <QColor>
 #include <QTextStream>
-#include <QApplication>
 #include <QLabel>
-#include <QListWidget>
+#include <QListView>
 #include <QVBoxLayout>
 #include <QIcon>
 #include <QLineEdit>
 #include <QMessageBox>
+#include <QStringListModel>
 
 #include "hwconsts.h"
 #include "mapContainer.h"
 #include "igbox.h"
+#include "HWApplication.h"
 
 HWMapContainer::HWMapContainer(QWidget * parent) :
     QWidget(parent),
@@ -46,10 +47,10 @@ HWMapContainer::HWMapContainer(QWidget * parent) :
     hhLimit = 18;
     templateFilter = 0;
 
-    mainLayout.setContentsMargins(QApplication::style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+    mainLayout.setContentsMargins(HWApplication::style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
         1,
-        QApplication::style()->pixelMetric(QStyle::PM_LayoutRightMargin),
-        QApplication::style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+        HWApplication::style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+        HWApplication::style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
 
     QWidget* mapWidget = new QWidget(this);
     mainLayout.addWidget(mapWidget, 0, 0, Qt::AlignHCenter);
@@ -63,8 +64,6 @@ HWMapContainer::HWMapContainer(QWidget * parent) :
     imageButt->setFlat(true);
     imageButt->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);//QSizePolicy::Minimum, QSizePolicy::Minimum);
     mapLayout->addWidget(imageButt, 0, 0, 1, 2);
-    //connect(imageButt, SIGNAL(clicked()), this, SLOT(setRandomSeed()));
-    //connect(imageButt, SIGNAL(clicked()), this, SLOT(setRandomTheme()));
     connect(imageButt, SIGNAL(clicked()), this, SLOT(setRandomMap()));
 
     chooseMap = new QComboBox(mapWidget);
@@ -85,16 +84,29 @@ QComboBox::tr("generated maze..."));
 
     int missionindex = chooseMap->count();
     numMissions = 0;
+    QFile mapLuaFile;
+    QFile mapCfgFile;
     for (int i = 0; i < mapList->size(); ++i) {
         QString map = (*mapList)[i];
-        QFile mapCfgFile(
-                QString("%1/Maps/%2/map.cfg")
-                .arg(datadir->absolutePath())
-                .arg(map));
-        QFile mapLuaFile(
-                QString("%1/Maps/%2/map.lua")
-                .arg(datadir->absolutePath())
+        mapCfgFile.setFileName(
+                QString("%1/Data/Maps/%2/map.cfg")
+                .arg(cfgdir->absolutePath())
                 .arg(map));
+        if (mapCfgFile.exists()) {
+            mapLuaFile.setFileName(
+                    QString("%1/Data/Maps/%2/map.lua")
+                    .arg(cfgdir->absolutePath())
+                    .arg(map));
+        } else {
+            mapCfgFile.setFileName(
+                    QString("%1/Maps/%2/map.cfg")
+                    .arg(datadir->absolutePath())
+                    .arg(map));
+            mapLuaFile.setFileName(
+                    QString("%1/Maps/%2/map.lua")
+                    .arg(datadir->absolutePath())
+                    .arg(map));
+        }
 
         if (mapCfgFile.open(QFile::ReadOnly)) {
             QString theme;
@@ -140,7 +152,7 @@ map, mapInfo);
     }
     chooseMap->insertSeparator(missionindex); // separator between missions and maps
 
-    connect(chooseMap, SIGNAL(currentIndexChanged(int)), this, SLOT(mapChanged(int)));
+    connect(chooseMap, SIGNAL(activated(int)), this, SLOT(mapChanged(int)));
     mapLayout->addWidget(chooseMap, 1, 1);
 
     QLabel * lblMap = new QLabel(tr("Map"), mapWidget);
@@ -149,32 +161,32 @@ map, mapInfo);
     lblFilter = new QLabel(tr("Filter"), mapWidget);
     mapLayout->addWidget(lblFilter, 2, 0);
 
-    CB_TemplateFilter = new QComboBox(mapWidget);
-    CB_TemplateFilter->addItem(tr("All"), 0);
-    CB_TemplateFilter->addItem(tr("Small"), 1);
-    CB_TemplateFilter->addItem(tr("Medium"), 2);
-    CB_TemplateFilter->addItem(tr("Large"), 3);
-    CB_TemplateFilter->addItem(tr("Cavern"), 4);
-    CB_TemplateFilter->addItem(tr("Wacky"), 5);
-    mapLayout->addWidget(CB_TemplateFilter, 2, 1);
+    cbTemplateFilter = new QComboBox(mapWidget);
+    cbTemplateFilter->addItem(tr("All"), 0);
+    cbTemplateFilter->addItem(tr("Small"), 1);
+    cbTemplateFilter->addItem(tr("Medium"), 2);
+    cbTemplateFilter->addItem(tr("Large"), 3);
+    cbTemplateFilter->addItem(tr("Cavern"), 4);
+    cbTemplateFilter->addItem(tr("Wacky"), 5);
+    mapLayout->addWidget(cbTemplateFilter, 2, 1);
 
-    connect(CB_TemplateFilter, SIGNAL(currentIndexChanged(int)), this, SLOT(templateFilterChanged(int)));
+    connect(cbTemplateFilter, SIGNAL(activated(int)), this, SLOT(setTemplateFilter(int)));
 
     maze_size_label = new QLabel(tr("Type"), mapWidget);
-    mainLayout.addWidget(maze_size_label, 2, 0);
+    mapLayout->addWidget(maze_size_label, 2, 0);
     maze_size_label->hide();
-    maze_size_selection = new QComboBox(mapWidget);
-    maze_size_selection->addItem(tr("Small tunnels"), 0);
-    maze_size_selection->addItem(tr("Medium tunnels"), 1);
-    maze_size_selection->addItem(tr("Large tunnels"), 2);
-    maze_size_selection->addItem(tr("Small floating islands"), 3);
-    maze_size_selection->addItem(tr("Medium floating islands"), 4);
-    maze_size_selection->addItem(tr("Large floating islands"), 5);
-    maze_size_selection->setCurrentIndex(1);
+    cbMazeSize = new QComboBox(mapWidget);
+    cbMazeSize->addItem(tr("Small tunnels"), 0);
+    cbMazeSize->addItem(tr("Medium tunnels"), 1);
+    cbMazeSize->addItem(tr("Large tunnels"), 2);
+    cbMazeSize->addItem(tr("Small floating islands"), 3);
+    cbMazeSize->addItem(tr("Medium floating islands"), 4);
+    cbMazeSize->addItem(tr("Large floating islands"), 5);
+    cbMazeSize->setCurrentIndex(1);
 
-    mapLayout->addWidget(maze_size_selection, 2, 1);
-    maze_size_selection->hide();
-    connect(maze_size_selection, SIGNAL(currentIndexChanged(int)), this, SLOT(setMaze_size(int)));
+    mapLayout->addWidget(cbMazeSize, 2, 1);
+    cbMazeSize->hide();
+    connect(cbMazeSize, SIGNAL(activated(int)), this, SLOT(setMazeSize(int)));
 
     gbThemes = new IconedGroupBox(mapWidget);
     gbThemes->setTitleTextPadding(80);
@@ -187,21 +199,18 @@ map, mapInfo);
     QVBoxLayout * gbTLayout = new QVBoxLayout(gbThemes);
     gbTLayout->setContentsMargins(0, 0, 0 ,0);
     gbTLayout->setSpacing(0);
-    lwThemes = new QListWidget(mapWidget);
-    lwThemes->setMinimumHeight(30);
-    lwThemes->setFixedWidth(140);
-    for (int i = 0; i < Themes->size(); ++i) {
-        QListWidgetItem * lwi = new QListWidgetItem();
-        lwi->setText(Themes->at(i));
-        lwi->setIcon(QIcon(QString("%1/Themes/%2/icon.png").arg(datadir->absolutePath()).arg(Themes->at(i))));
-        //lwi->setTextAlignment(Qt::AlignHCenter);
-        lwThemes->addItem(lwi);
-    }
-    connect(lwThemes, SIGNAL(currentRowChanged(int)), this, SLOT(themeSelected(int)));
+    lvThemes = new QListView(mapWidget);
+    lvThemes->setMinimumHeight(30);
+    lvThemes->setFixedWidth(140);
+    lvThemes->setModel(themesModel);
+    lvThemes->setIconSize(QSize(16, 16));
+    lvThemes->setEditTriggers(QListView::NoEditTriggers);
+
+    connect(lvThemes->selectionModel(), SIGNAL(currentRowChanged( const QModelIndex &, const QModelIndex &)), this, SLOT(themeSelected( const QModelIndex &, const QModelIndex &)));
 
     // override default style to tighten up theme scroller
-    lwThemes->setStyleSheet(QString(
-        "QListWidget{"
+    lvThemes->setStyleSheet(QString(
+        "QListView{"
             "border: solid;"
             "border-width: 0px;"
             "border-radius: 0px;"
@@ -213,8 +222,8 @@ map, mapInfo);
         )
     );
 
-    gbTLayout->addWidget(lwThemes);
-    lwThemes->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
+    gbTLayout->addWidget(lvThemes);
+    lvThemes->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
 
     mapLayout->setSizeConstraint(QLayout::SetFixedSize);
 
@@ -278,11 +287,10 @@ void HWMapContainer::mapChanged(int index)
         updatePreview();
         gbThemes->show();
         lblFilter->show();
-        CB_TemplateFilter->show();
+        cbTemplateFilter->show();
         maze_size_label->hide();
-        maze_size_selection->hide();
+        cbMazeSize->hide();
         emit mapChanged("+rnd+");
-        emit mapgenChanged(mapgen);
         emit themeChanged(chooseMap->itemData(index).toList()[1].toString());
         break;
     case MAPGEN_MAZE:
@@ -290,11 +298,10 @@ void HWMapContainer::mapChanged(int index)
         updatePreview();
         gbThemes->show();
         lblFilter->hide();
-        CB_TemplateFilter->hide();
+        cbTemplateFilter->hide();
         maze_size_label->show();
-        maze_size_selection->show();
+        cbMazeSize->show();
         emit mapChanged("+maze+");
-        emit mapgenChanged(mapgen);
         emit themeChanged(chooseMap->itemData(index).toList()[1].toString());
         break;
     case MAPGEN_DRAWN:
@@ -302,22 +309,24 @@ void HWMapContainer::mapChanged(int index)
         updatePreview();
         gbThemes->show();
         lblFilter->hide();
-        CB_TemplateFilter->hide();
+        cbTemplateFilter->hide();
         maze_size_label->hide();
-        maze_size_selection->hide();
+        cbMazeSize->hide();
         emit mapChanged("+drawn+");
-        emit mapgenChanged(mapgen);
         emit themeChanged(chooseMap->itemData(index).toList()[1].toString());
         break;
     default:
+        mapgen = MAPGEN_MAP;
         updatePreview();
         gbThemes->hide();
         lblFilter->hide();
-        CB_TemplateFilter->hide();
+        cbTemplateFilter->hide();
         maze_size_label->hide();
-        maze_size_selection->hide();
+        cbMazeSize->hide();
         emit mapChanged(chooseMap->itemData(index).toList()[0].toString());
     }
+
+    emit mapgenChanged(mapgen);
 }
 
 // Should this add text to identify map size?
@@ -355,14 +364,14 @@ void HWMapContainer::askForGeneratedPreview()
     pMap->getImage(m_seed,
                    getTemplateFilter(),
                    get_mapgen(),
-                   get_maze_size(),
+                   getMazeSize(),
                    getDrawnMapData()
             );
 }
 
-void HWMapContainer::themeSelected(int currentRow)
+void HWMapContainer::themeSelected(const QModelIndex & current, const QModelIndex &)
 {
-    QString theme = Themes->at(currentRow);
+    QString theme = current.data().toString();
     QList<QVariant> mapInfo;
     mapInfo.push_back(QString("+rnd+"));
     mapInfo.push_back(theme);
@@ -373,7 +382,8 @@ void HWMapContainer::themeSelected(int currentRow)
     chooseMap->setItemData(1, mapInfo);
     mapInfo[0] = QString("+drawn+");
     chooseMap->setItemData(2, mapInfo);
-    gbThemes->setIcon(QIcon(QString("%1/Themes/%2/icon@2x.png").arg(datadir->absolutePath()).arg(theme)));
+
+    gbThemes->setIcon(qVariantValue<QIcon>(current.data(Qt::UserRole)));
     emit themeChanged(theme);
 }
 
@@ -416,7 +426,7 @@ QString HWMapContainer::getCurrentWeapons() const
 
 quint32 HWMapContainer::getTemplateFilter() const
 {
-    return CB_TemplateFilter->itemData(CB_TemplateFilter->currentIndex()).toInt();
+    return cbTemplateFilter->itemData(cbTemplateFilter->currentIndex()).toInt();
 }
 
 void HWMapContainer::resizeEvent ( QResizeEvent * event )
@@ -425,16 +435,21 @@ void HWMapContainer::resizeEvent ( QResizeEvent * event )
   //imageButt->setIconSize(imageButt->size());
 }
 
-void HWMapContainer::setSeed(const QString & seed)
+void HWMapContainer::intSetSeed(const QString & seed)
 {
     m_seed = seed;
     if (seed != seedEdit->text())
         seedEdit->setText(seed);
-    if (chooseMap->currentIndex() < MAPGEN_MAP)
+}
+
+void HWMapContainer::setSeed(const QString & seed)
+{
+    intSetSeed(seed);
+    if (chooseMap->currentIndex() < MAPGEN_DRAWN)
         updatePreview();
 }
 
-void HWMapContainer::setMap(const QString & map)
+void HWMapContainer::intSetMap(const QString & map)
 {
     int id = 0;
     for(int i = 0; i < chooseMap->count(); i++)
@@ -452,15 +467,21 @@ void HWMapContainer::setMap(const QString & map)
             pMap = 0;
         }
         chooseMap->setCurrentIndex(id);
-        updatePreview();
     }
 }
 
+void HWMapContainer::setMap(const QString &map)
+{
+    intSetMap(map);
+    updatePreview();
+}
+
 void HWMapContainer::setTheme(const QString & theme)
 {
-    QList<QListWidgetItem *> items = lwThemes->findItems(theme, Qt::MatchExactly);
-    if(items.size())
-        lwThemes->setCurrentItem(items.at(0));
+    QModelIndexList mdl = themesModel->match(themesModel->index(0), Qt::DisplayRole, theme);
+
+    if(mdl.size())
+        lvThemes->setCurrentIndex(mdl.at(0));
 }
 
 void HWMapContainer::setRandomMap()
@@ -488,15 +509,14 @@ void HWMapContainer::setRandomStatic()
 {
     int i = MAPGEN_MAP + 3 + numMissions + rand() % (chooseMap->count() - MAPGEN_MAP - 3 - numMissions);
     chooseMap->setCurrentIndex(i);
-    setRandomSeed();
+    updatePreview();
 }
 
 void HWMapContainer::setRandomMission()
 {
     int i = MAPGEN_MAP + 2 + rand() % numMissions;
-    qDebug() << i << MAPGEN_MAP << numMissions;
     chooseMap->setCurrentIndex(i);
-    setRandomSeed();
+    updatePreview();
 }
 
 void HWMapContainer::setRandomSeed()
@@ -510,19 +530,20 @@ void HWMapContainer::setRandomSeed()
 
 void HWMapContainer::setRandomTheme()
 {
-    if(!Themes->size()) return;
-    quint32 themeNum = rand() % Themes->size();
-    lwThemes->setCurrentRow(themeNum);
+    if(!themesModel->rowCount()) return;
+    quint32 themeNum = rand() % themesModel->rowCount();
+    lvThemes->setCurrentIndex(themesModel->index(themeNum));
+}
+
+void HWMapContainer::intSetTemplateFilter(int filter)
+{
+    cbTemplateFilter->setCurrentIndex(filter);
+    emit newTemplateFilter(filter);
 }
 
 void HWMapContainer::setTemplateFilter(int filter)
 {
-    CB_TemplateFilter->setCurrentIndex(filter);
-}
-
-void HWMapContainer::templateFilterChanged(int filter)
-{
-    emit newTemplateFilter(filter);
+    intSetTemplateFilter(filter);
     updatePreview();
 }
 
@@ -531,23 +552,36 @@ MapGenerator HWMapContainer::get_mapgen(void) const
     return mapgen;
 }
 
-int HWMapContainer::get_maze_size(void) const
+int HWMapContainer::getMazeSize(void) const
 {
-    return maze_size_selection->currentIndex();
+    return cbMazeSize->currentIndex();
 }
 
-void HWMapContainer::setMaze_size(int size)
+void HWMapContainer::intSetMazeSize(int size)
 {
-    maze_size_selection->setCurrentIndex(size);
-    emit maze_sizeChanged(size);
+    cbMazeSize->setCurrentIndex(size);
+    emit mazeSizeChanged(size);
+}
+
+void HWMapContainer::setMazeSize(int size)
+{
+    intSetMazeSize(size);
     updatePreview();
 }
 
+void HWMapContainer::intSetMapgen(MapGenerator m)
+{
+    mapgen = m;
+
+    if(m != MAPGEN_MAP)
+        chooseMap->setCurrentIndex(m);
+
+    emit mapgenChanged(m);
+}
+
 void HWMapContainer::setMapgen(MapGenerator m)
 {
-    mapgen = m;
-    chooseMap->setCurrentIndex(m);
-    emit mapgenChanged(m);
+    intSetMapgen(m);
     updatePreview();
 }
 
@@ -610,8 +644,10 @@ void HWMapContainer::updatePreview()
         break;
     default:
         QPixmap mapImage;
-        qDebug() << "Map data" << curIndex << chooseMap->currentText() << chooseMap->itemData(curIndex);
-        if(!mapImage.load(datadir->absolutePath() + "/Maps/" + chooseMap->itemData(curIndex).toList()[0].toString() + "/preview.png")) {
+        QFile tmpfile;
+        tmpfile.setFileName(cfgdir->absolutePath() + "/Data/Maps/" + chooseMap->itemData(curIndex).toList()[0].toString() + "/preview.png");
+        if (!tmpfile.exists()) tmpfile.setFileName(datadir->absolutePath() + "/Maps/" + chooseMap->itemData(curIndex).toList()[0].toString() + "/preview.png");
+        if(!mapImage.load(QFileInfo(tmpfile).absoluteFilePath())) {
             imageButt->setIcon(QIcon());
             return;
         }
@@ -620,3 +656,14 @@ void HWMapContainer::updatePreview()
         addInfoToPreview(mapImage);
     }
 }
+
+void HWMapContainer::setAllMapParameters(const QString &map, MapGenerator m, int mazesize, const QString &seed, int tmpl)
+{
+    intSetMap(map);
+    intSetMapgen(m);
+    intSetMazeSize(mazesize);
+    intSetSeed(seed);
+    intSetTemplateFilter(tmpl);
+
+    updatePreview();
+}
