@@ -1,6 +1,7 @@
 /*
  * Hedgewars, a free turn based strategy game
  * Copyright (c) 2009 Martin Minarik <ttsmj@pokec.sk>
+ * Copyright (c) 2009-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +31,9 @@ public:
     HWNamegen();
     ~HWNamegen();
 
-    void TeamRandomName(HWTeam*& team, const int &i);
+    void TeamRandomName(HWTeam*& team, const int HedgehogNumber);
     void TeamRandomNames(HWTeam*& team, const bool changeteamname);
-    void RandomNameByHat(HWTeam*& team, const int &i);
+    void RandomNameByHat(HWTeam*& team, const int HedgehogNumber);
 
 private:
 
@@ -42,6 +43,9 @@ private:
         void TypesLoad();
         void DictLoad(const QString filename, QStringList &list);
         void HatCfgLoad(const QString hatname, QStringList &list);
+
+		QString GetRandomGrave();
+		QString GetRandomFort();
 };
 
 
