@@ -1,7 +1,7 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2006-2008 Ulyanov Igor <iulyanov@gmail.com>
- * Copyright (c) 2010 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2006-2008 Igor Ulyanov <iulyanov@gmail.com>
+ * Copyright (c) 2008-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,10 @@
 #include "gamecfgwidget.h"
 #include "teamselect.h"
 #include "misc.h"
+/* only to get the ignoreList from the chat widget */
+#include "hwform.h"
+#include "pageroomslist.h"
+#include "chatwidget.h"
 
 char delimeter='\n';
 
@@ -66,7 +70,16 @@ HWNewNet::~HWNewNet()
 
 void HWNewNet::Connect(const QString & hostName, quint16 port, const QString & nick)
 {
-    mynick = nick.isEmpty() ? QLineEdit::tr("unnamed") : nick;
+    mynick = nick;
+    while (mynick.isEmpty()) {
+        mynick = QInputDialog::getText(m_pGameCFGWidget,
+                 QObject::tr("Nickname"),
+                 QObject::tr("Please enter your nickname"),
+                 QLineEdit::Normal,
+                 QDir::home().dirName());
+        config->setValue("net/nick",mynick);
+        config->updNetNick();
+    }
     myhost = hostName + QString(":%1").arg(port);
     NetSocket.connectToHost(hostName, port);
 }
@@ -185,6 +198,7 @@ void HWNewNet::OnDisconnect()
 void HWNewNet::displayError(QAbstractSocket::SocketError socketError)
 {
     emit Disconnected();
+    m_game_connected = false;
 
     switch (socketError) {
         case QAbstractSocket::RemoteHostClosedError:
@@ -236,6 +250,12 @@ void HWNewNet::ParseCmd(const QStringList & lst)
     }
 
     if (lst[0] == "CONNECTED") {
+        if(lst.size() < 3 || lst[2].toInt() < cMinServerVersion)
+        {
+            // TODO: Warn user, disconnect
+            qWarning() << "Server too old";
+        }
+
         RawSendNet(QString("NICK%1%2").arg(delimeter).arg(mynick));
         RawSendNet(QString("PROTO%1%2").arg(delimeter).arg(*cProtoVer));
         netClientState = 1;
@@ -276,7 +296,7 @@ void HWNewNet::ParseCmd(const QStringList & lst)
             return;
         }
         if (netClientState == 2)
-            emit chatStringLobby(HWProto::formatChatMsg(lst[1], lst[2]));
+            emit chatStringLobby(lst[1], HWProto::formatChatMsgForFrontend(lst[2]));
         else
             emit chatStringFromNet(HWProto::formatChatMsg(lst[1], lst[2]));
         return;
@@ -312,33 +332,36 @@ void HWNewNet::ParseCmd(const QStringList & lst)
         return;
     }
 
-    if (lst[0] == "READY") {
-        if(lst.size() < 2)
+    if (lst[0] == "CLIENT_FLAGS")
+    {
+        if(lst.size() < 3 || lst[1].size() < 2)
         {
-            qWarning("Net: Malformed READY message");
+            qWarning("Net: Malformed CLIENT_FLAGS message");
             return;
         }
-        for(int i = 1; i < lst.size(); ++i)
-        {
-            if (lst[i] == mynick)
-                emit setMyReadyStatus(true);
-            emit setReadyStatus(lst[i], true);
-        }
-        return;
-    }
 
-    if (lst[0] == "NOT_READY") {
-        if(lst.size() < 2)
+        QString flags = lst[1];
+        bool setFlag = flags[0] == '+';
+
+        while(flags.size() > 1)
         {
-            qWarning("Net: Malformed NOT_READY message");
-            return;
-        }
-        for(int i = 1; i < lst.size(); ++i)
-        {
-            if (lst[i] == mynick)
-                emit setMyReadyStatus(false);
-            emit setReadyStatus(lst[i], false);
+            flags.remove(0, 1);
+            char c = flags[0].toAscii();
+
+            switch(c)
+            {
+            case 'r':
+                {
+                    for(int i = 2; i < lst.size(); ++i)
+                    {
+                        if (lst[i] == mynick)
+                            emit setMyReadyStatus(setFlag);
+                        emit setReadyStatus(lst[i], setFlag);
+                    }
+                }
+            }
         }
+
         return;
     }
 
@@ -395,8 +418,15 @@ void HWNewNet::ParseCmd(const QStringList & lst)
                 if (isChief)
                     emit configAsked();
             }
-            emit nickAdded(lst[i], isChief && (lst[i] != mynick));
-            emit chatStringFromNet(tr("%1 *** %2 has joined the room").arg('\x03').arg(lst[i]));
+            if (lst[i] != mynick && isChief && config->Form->ui.pageRoomsList->chatWidget->ignoreList.contains(lst[i], Qt::CaseInsensitive) && !config->Form->ui.pageRoomsList->chatWidget->friendsList.contains(lst[i], Qt::CaseInsensitive))
+            {
+                kickPlayer(lst[i]);
+            }
+            else
+            {
+                emit nickAdded(lst[i], isChief && (lst[i] != mynick));
+                emit chatStringFromNet(tr("%1 *** %2 has joined the room").arg('\x03').arg(lst[i]));
+            }
         }
         return;
     }
@@ -418,7 +448,7 @@ void HWNewNet::ParseCmd(const QStringList & lst)
             }
 
             emit nickAddedLobby(lst[i], false);
-            emit chatStringLobby(tr("%1 *** %2 has joined").arg('\x03').arg(lst[i]));
+            emit chatStringLobby(lst[i], tr("%1 *** %2 has joined").arg('\x03').arg("|nick|"));
         }
         return;
     }
@@ -471,24 +501,48 @@ void HWNewNet::ParseCmd(const QStringList & lst)
         bool ok = false;
         int passLength = config->value("net/passwordlength", 0).toInt();
         QString hash = config->value("net/passwordhash", "").toString();
-        QString password = QInputDialog::getText(0, tr("Password"), tr("Your nickname %1 is\nregistered on Hedgewars.org\nPlease provide your password below\nor pick another nickname in game config:").arg(mynick), QLineEdit::Password, passLength==0?NULL:QString(passLength,'\0'), &ok);
+        
+        // If the password is blank, ask the user to enter one in
+        if (passLength == 0)
+        {
+            QString password = QInputDialog::getText(m_pGameCFGWidget, tr("Password"), tr("Your nickname %1 is\nregistered on Hedgewars.org\nPlease provide your password below\nor pick another nickname in game config:").arg(mynick), QLineEdit::Password, passLength==0?NULL:QString(passLength,'\0'), &ok);
 
-        if (!ok) {
-            Disconnect();
-            emit Disconnected();
-            return;
-        }
-
-        if (!passLength || password!=QString(passLength, '\0')) {
+            if (!ok) {
+                Disconnect();
+                emit Disconnected();
+                return;
+            }
+            
             hash = QCryptographicHash::hash(password.toLatin1(), QCryptographicHash::Md5).toHex();
             config->setValue("net/passwordhash", hash);
             config->setValue("net/passwordlength", password.size());
+            config->setNetPasswordLength(password.size());
         }
 
         RawSendNet(QString("PASSWORD%1%2").arg(delimeter).arg(hash));
         return;
     }
 
+    if (lst[0] == "NOTICE") {
+        if(lst.size() < 2)
+        {
+            qWarning("Net: Bad NOTICE message");
+            return;
+        }
+
+        bool ok;
+        int n = lst[1].toInt(&ok);
+        if(!ok)
+        {
+            qWarning("Net: Bad NOTICE message");
+            return;
+        }
+
+        handleNotice(n);
+
+        return;
+    }
+
     if (lst[0] == "TEAM_ACCEPTED") {
         if (lst.size() != 2)
         {
@@ -560,6 +614,12 @@ void HWNewNet::ParseCmd(const QStringList & lst)
             qWarning("Net: Bad BYE message");
             return;
         }
+        if (lst[1] == "Authentication failed")
+        {
+            // Set the password blank if case the user tries to join and enter his password again
+            config->setValue("net/passwordlength", 0);
+            config->setNetPasswordLength(0);
+        }
         emit showMessage(HWNewNet::tr("Quit reason: ") + lst[1]);
         return;
     }
@@ -673,10 +733,10 @@ bool HWNewNet::isRoomChief()
     return isChief;
 }
 
-void HWNewNet::gameFinished()
+void HWNewNet::gameFinished(bool correctly)
 {
     if (netClientState == 5) netClientState = 3;
-    RawSendNet(QString("ROUNDFINISHED"));
+    RawSendNet(QString("ROUNDFINISHED%1%2").arg(delimeter).arg(correctly ? "1" : "0"));
 }
 
 void HWNewNet::banPlayer(const QString & nick)
@@ -707,6 +767,12 @@ void HWNewNet::startGame()
     RawSendNet(QString("START_GAME"));
 }
 
+void HWNewNet::updateRoomName(const QString & name)
+{
+    RawSendNet(QString("ROOM_NAME%1%2").arg(delimeter).arg(name));
+}
+
+
 void HWNewNet::toggleRestrictJoins()
 {
     RawSendNet(QString("TOGGLE_RESTRICT_JOINS"));
@@ -752,3 +818,29 @@ void HWNewNet::askServerVars()
 {
     RawSendNet(QString("GET_SERVER_VAR"));
 }
+
+void HWNewNet::handleNotice(int n)
+{
+    switch(n)
+    {
+        case 0:
+        {
+            bool ok = false;
+            QString newNick = QInputDialog::getText(0, tr("Nickname"), tr("Some one already uses\n your nickname %1\non the server.\nPlease pick another nickname:").arg(mynick), QLineEdit::Normal, mynick, &ok);
+
+            if (!ok || newNick.isEmpty()) {
+                Disconnect();
+                emit Disconnected();
+                return;
+            }
+
+            config->setValue("net/nick", newNick);
+            config->updNetNick();
+            mynick = newNick;
+
+            RawSendNet(QString("NICK%1%2").arg(delimeter).arg(newNick));
+
+            break;
+        }
+    }
+}
