@@ -1,6 +1,7 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2006, 2007 Ulyanov Igor <iulyanov@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2006-2008 Igor Ulyanov <iulyanov@gmail.com>
+ * Copyright (c) 2008-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,10 +40,15 @@ class HWNewNet : public QObject
 
  public:
   HWNewNet(GameUIConfig * config, GameCFGWidget* pGameCFGWidget, TeamSelWidget* pTeamSelWidget);
+  ~HWNewNet();
   void Connect(const QString & hostName, quint16 port, const QString & nick);
   void Disconnect();
-  void JoinGame(const QString & game);
-  void StartGame();
+  bool isRoomChief();
+  bool isInRoom();
+  int getClientState();
+  QString getNick();
+  QString getRoom();
+  QString getHost();
 
  private:
   GameUIConfig* config;
@@ -51,15 +57,12 @@ class HWNewNet : public QObject
 
   bool isChief;
   QString mynick;
+  QString myroom;
+  QString myhost;
   QTcpSocket NetSocket;
   QString seed;
   bool m_game_connected;
 
-  QMap<unsigned int, QString> m_networkToLocalteams; // key is netID, value is local team name
-
-  void ConfigAsked();
-  void RunGame();
-
   template <typename T>
   void SendCfgStrNet(T a) {
     QByteArray strmsg;
@@ -79,53 +82,90 @@ class HWNewNet : public QObject
     emit FromNet(enginemsg);
   }
 
+  QStringList cmdbuf;
+
   void RawSendNet(const QString & buf);
   void RawSendNet(const QByteArray & buf);
-  void ParseLine(const QByteArray & line);
+  void ParseCmd(const QStringList & lst);
+  void handleNotice(int n);
+
+  int loginStep;
+  int netClientState;
 
  signals:
   void AskForRunGame();
   void Connected();
   void Disconnected();
   void EnteredGame();
-  void nickAdded(const QString& nick);
+  void LeftRoom();
+  void nickAdded(const QString& nick, bool notifyNick);
   void nickRemoved(const QString& nick);
+  void nickAddedLobby(const QString& nick, bool notifyNick);
+  void nickRemovedLobby(const QString& nick);
   void FromNet(const QByteArray & buf);
-  void AddNetTeam(const HWTeam&);
+  void adminAccess(bool);
+  void roomMaster(bool);
 
-  void seedChanged(const QString & seed);
-  void mapChanged(const QString & map);
-  void themeChanged(const QString & theme);
-  void initHealthChanged(quint32 health);
-  void turnTimeChanged(quint32 time);
-  void fortsModeChanged(bool value);
+  void netSchemeConfig(QStringList &);
+  void paramChanged(const QString & param, const QStringList & value);
+  void configAsked();
+
+  void AddNetTeam(const HWTeam&);
   void hhnumChanged(const HWTeam&);
   void teamColorChanged(const HWTeam&);
-  void chatStringFromNet(const QStringList&);
-  void ammoChanged(const QString& name, const QString& ammo);
+  void chatStringLobby(const QString&);
+  void chatStringLobby(const QString&, const QString&);
+  void chatStringFromNet(const QString&);
+  void chatStringFromMe(const QString&);
+  void chatStringFromMeLobby(const QString&);
+
+  void roomsList(const QStringList&);
+  void serverMessage(const QString &);
+  void serverMessageNew(const QString &);
+  void serverMessageOld(const QString &);
+  void latestProtocolVar(int);
+
+  void setReadyStatus(const QString & nick, bool isReady);
+  void setMyReadyStatus(bool isReady);
+  void showMessage(const QString &);
 
  public slots:
+  void ToggleReady();
   void chatLineToNet(const QString& str);
+  void chatLineToLobby(const QString& str);
+  void SendTeamMessage(const QString& str);
   void SendNet(const QByteArray & buf);
   void AddTeam(const HWTeam & team);
   void RemoveTeam(const HWTeam& team);
-  void onSeedChanged(const QString & seed);
-  void onMapChanged(const QString & map);
-  void onThemeChanged(const QString & theme);
-  void onInitHealthChanged(quint32 health);
-  void onTurnTimeChanged(quint32 time);
-  void onFortsModeChanged(bool value);
   void onHedgehogsNumChanged(const HWTeam& team);
   void onTeamColorChanged(const HWTeam& team);
-  void onWeaponsNameChanged(const QString& name, const QString& ammo);
+  void onParamChanged(const QString & param, const QStringList & value);
+
+  void setServerMessageNew(const QString &);
+  void setServerMessageOld(const QString &);
+  void setLatestProtocolVar(int proto);
+  void askServerVars();
+
+  void JoinRoom(const QString & room);
+  void CreateRoom(const QString & room);
+  void updateRoomName(const QString &);
+  void askRoomsList();
+  void gameFinished(bool correcly);
+  void banPlayer(const QString &);
+  void kickPlayer(const QString &);
+  void infoPlayer(const QString &);
+  void followPlayer(const QString &);
+  void startGame();
+  void toggleRestrictJoins();
+  void toggleRestrictTeamAdds();
+  void partRoom();
+  void clearAccountsCache();
 
  private slots:
   void ClientRead();
   void OnConnect();
   void OnDisconnect();
-  //void Perform();
-  void displayError(QAbstractSocket::SocketError socketError);
-  //void FlushNetBuf();
+  void displayError(QAbstractSocket::SocketError socketError); 
 };
 
 #endif // _NEW_NETCLIENT_INCLUDED
