@@ -1,6 +1,6 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2005-2010 Andrey Korotaev <unC0Rr@gmail.com>
+ * Copyright (c) 2005-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,14 +18,14 @@
 
 #include <QFile>
 #include <QTextStream>
-#include <QApplication>
 #include <QStringList>
 #include <QLineEdit>
 #include <QCryptographicHash>
 #include <QSettings>
+
 #include "team.h"
 #include "hwform.h"
-#include "pages.h"
+#include "pageeditteam.h"
 #include "hwconsts.h"
 #include "hats.h"
 
@@ -38,7 +38,7 @@ HWTeam::HWTeam(const QString & teamname) :
     OldTeamName = TeamName;
     for (int i = 0; i < 8; i++)
     {
-        Hedgehogs[i].Name.sprintf("hedgehog %d", i);
+        Hedgehogs[i].Name = (QLineEdit::tr("hedgehog %1").arg(i+1));
         Hedgehogs[i].Hat = "NoHat";
     }
     Grave = "Statue";
@@ -125,7 +125,7 @@ bool HWTeam::LoadFromFile()
     for(int i = 0; i < 8; i++)
     {
         QString hh = QString("Hedgehog%1/").arg(i);
-        Hedgehogs[i].Name = teamfile.value(hh + "Name", QString("hedgehog %1").arg(i)).toString();
+        Hedgehogs[i].Name = teamfile.value(hh + "Name", QString("hedgehog %1").arg(i+1)).toString();
         Hedgehogs[i].Hat = teamfile.value(hh + "Hat", "NoHat").toString();
         Hedgehogs[i].Rounds = teamfile.value(hh + "Rounds", 0).toInt();
         Hedgehogs[i].Kills = teamfile.value(hh + "Kills", 0).toInt();
