@@ -1,6 +1,7 @@
 /*
  * Hedgewars, a free turn based strategy game
- * Copyright (c) 2006, 2007 Ulyanov Igor <iulyanov@gmail.com>
+ * Copyright (c) 2006-2007 Igor Ulyanov <iulyanov@gmail.com>
+ * Copyright (c) 2007-2011 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +49,7 @@ TeamShowWidget::TeamShowWidget(HWTeam team, bool isPlaying, QWidget * parent) :
         QIcon(QString(":/res/botlevels/net%1.png").arg(m_team.difficulty))
         : QIcon(QString(":/res/botlevels/%1.png").arg(m_team.difficulty));
 
-    butt = new QPushButton(difficultyIcon, team.TeamName, this);
+    butt = new QPushButton(difficultyIcon, team.TeamName.replace("&","&&"), this);
     butt->setFlat(true);
     butt->setToolTip(team.Owner);
     mainLayout.addWidget(butt);
