@@ -5,11 +5,26 @@
     <name>AmmoSchemeModel</name>
     <message>
         <source>new</source>
-        <translation>Neu</translation>
+        <translation>neu</translation>
     </message>
     <message>
         <source>copy of</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopie von</translation>
+    </message>
+</context>
+<context>
+    <name>DrawMapWidget</name>
+    <message>
+        <source>File error</source>
+        <translation>Dateifehler</translation>
+    </message>
+    <message>
+        <source>Cannot open file &apos;%1&apos; for writing</source>
+        <translation>Datei &apos;%1&apos; konnte nicht für Schreibzugriff geöffnet werden.</translation>
+    </message>
+    <message>
+        <source>Cannot read file &apos;%1&apos;</source>
+        <translation>Datei &apos;%1&apos; konnte nicht gelese werden.</translation>
     </message>
 </context>
 <context>
@@ -46,7 +61,7 @@
     </message>
     <message>
         <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
-        <translation type="unfinished"></translation>
+        <translation>Wenn diese Option aktiviert ist, wird durch Auswählen eines Spielprofils auch automatisch Waffen ausgewählt</translation>
     </message>
 </context>
 <context>
@@ -108,6 +123,14 @@
         <comment>File Types</comment>
         <translation>Hedgewars gespeichertes Spiel</translation>
     </message>
+    <message>
+        <source>Demo name</source>
+        <translation>Demo-Name</translation>
+    </message>
+    <message>
+        <source>Demo name:</source>
+        <translation>Demo-Name:</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
@@ -192,11 +215,11 @@
     </message>
     <message>
         <source>Seed</source>
-        <translation type="unfinished"></translation>
+        <translation>Seed</translation>
     </message>
     <message>
         <source>Set</source>
-        <translation type="unfinished"></translation>
+        <translation>Setzen</translation>
     </message>
 </context>
 <context>
@@ -278,6 +301,20 @@ auf Hedgewars.org registriert.
 Bitte gib dein Passwort ein oder
 wähle einen anderen Spitznamen:</translation>
     </message>
+    <message>
+        <source>Nickname</source>
+        <translation>Spitzname</translation>
+    </message>
+    <message>
+        <source>Some one already uses
+ your nickname %1
+on the server.
+Please pick another nickname:</source>
+        <translation>Jemand verwendet
+deinen Spiznamen %1 
+bereits auf dem Server.
+Bitte wähle einen anderen Spitznamen:</translation>
+    </message>
 </context>
 <context>
     <name>KB</name>
@@ -331,36 +368,44 @@ wähle einen anderen Spitznamen:</translation>
         <source>Connecting...</source>
         <translation>Verbinde ...</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
 </context>
 <context>
     <name>PageDrawMap</name>
     <message>
         <source>Undo</source>
-        <translation type="unfinished"></translation>
+        <translation>Rückgängig</translation>
     </message>
     <message>
         <source>Clear</source>
-        <translation type="unfinished"></translation>
+        <translation>Löschen</translation>
     </message>
     <message>
         <source>Load</source>
-        <translation type="unfinished">Laden</translation>
+        <translation>Laden</translation>
     </message>
     <message>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Sichern</translation>
     </message>
     <message>
         <source>Load drawn map</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
-        <translation type="unfinished"></translation>
+        <translation>Gezeichnete Karte laden</translation>
     </message>
     <message>
         <source>Save drawn map</source>
-        <translation type="unfinished"></translation>
+        <translation>Gezeichnete Karte sichern</translation>
+    </message>
+    <message>
+        <source>Drawn Maps</source>
+        <translation>Gezeichnete Karten</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>Alle Dateien</translation>
     </message>
 </context>
 <context>
@@ -565,7 +610,7 @@ wähle einen anderen Spitznamen:</translation>
     <message>
         <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
         <comment>Tips</comment>
-        <translation>Die Windowsversion von Hedgewars unterstützt Xfire. Füge Hedgewars zu der Spieleliste hinzu, sodass deine Freunde sehen können wann du spielst.</translation>
+        <translation type="obsolete">Die Windowsversion von Hedgewars unterstützt Xfire. Füge Hedgewars zu der Spieleliste hinzu, sodass deine Freunde sehen können wann du spielst.</translation>
     </message>
     <message>
         <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
@@ -635,7 +680,7 @@ wähle einen anderen Spitznamen:</translation>
     <message>
         <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
         <comment>Tips</comment>
-        <translation>Die zielsuchende Biene ist schwierig in der Handhabung. Ihr Wendekreis hängt von ihrer Geschwindigkeit ab, also versuche nicht die volle Kraft zu benutzen.</translation>
+        <translation type="obsolete">Die zielsuchende Biene ist schwierig in der Handhabung. Ihr Wendekreis hängt von ihrer Geschwindigkeit ab, also versuche nicht die volle Kraft zu benutzen.</translation>
     </message>
     <message>
         <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
@@ -665,7 +710,7 @@ wähle einen anderen Spitznamen:</translation>
     <message>
         <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
         <comment>Tips</comment>
-        <translation>Benutze den Molotov-Cocktail um kurzzeitig Igel daran zu hindern Tunnel zu durchqueren oder Plattformen zu erklimmen.</translation>
+        <translation type="obsolete">Benutze den Molotov-Cocktail um kurzzeitig Igel daran zu hindern Tunnel zu durchqueren oder Plattformen zu erklimmen.</translation>
     </message>
     <message>
         <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
@@ -715,12 +760,31 @@ wähle einen anderen Spitznamen:</translation>
     <message>
         <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
         <comment>Tips</comment>
-        <translation type="unfinished"></translation>
+        <translation>Du findest die Hedgewars Konfigurationsdateien unter &quot;Library/Application Support/Hedgewars&quot; in deinem Home-Verzeichnis. Erstelle Backups oder kopiere deine Dateien, aber editiere sie besser nicht selbst.</translation>
     </message>
     <message>
         <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
         <comment>Tips</comment>
-        <translation type="unfinished"></translation>
+        <translation>Du findest die Hedgewars Konfigurationsdateien unter &quot;.hedgewars&quot; in deinem Home-Verzeichnis. Erstelle Backups oder kopiere deine Dateien, aber editiere sie besser nicht selbst.</translation>
+    </message>
+    <message>
+        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgewars to its game list so your friends can see you playing.</source>
+        <comment>Tips</comment>
+        <translation>Die Windows version von Hedgewars unterstützt Xfire. Füge Hedgewars zu deiner Spieleliste hinzu damit deine Freunde dich spielen sehen können.</translation>
+    </message>
+    <message>
+        <source>Use the Molotov or Flame Thrower to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
+        <comment>Tips</comment>
+        <translation>Benutze den Molotov-Cocktail oder den Flammenwerfer um Igel vorübergehend am passieren von Gelände wie z.B. Tunnels oder Platformen zu hindern.</translation>
+    </message>
+    <message>
+        <source>The Homing Bee can be tricky to use. Its turn radius depends on its velocity, so try to not use full power.</source>
+        <comment>Tips</comment>
+        <translation>Die Verwendung der Zielsuchende Biene ist ein bisschen knifflig. Ihr Wenderadius hängt von der Geschwindigkeit ab, versuche sie also nicht mit voller Stärke wegzuschießen.</translation>
+    </message>
+    <message>
+        <source>Downloadable Content</source>
+        <translation>Herunterladbare Inhalte</translation>
     </message>
 </context>
 <context>
@@ -747,6 +811,18 @@ wähle einen anderen Spitznamen:</translation>
         <source>Control</source>
         <translation>Steuerung</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Fehler</translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Bitte einen Raumnamen eingeben</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
 </context>
 <context>
     <name>PageNetType</name>
@@ -791,27 +867,27 @@ wähle einen anderen Spitznamen:</translation>
     </message>
     <message>
         <source>New scheme</source>
-        <translation type="unfinished"></translation>
+        <translation>Neues Spielprofil</translation>
     </message>
     <message>
         <source>Edit scheme</source>
-        <translation type="unfinished"></translation>
+        <translation>Spielprofil bearbeiten</translation>
     </message>
     <message>
         <source>Delete scheme</source>
-        <translation type="unfinished"></translation>
+        <translation>Spielprofil löschen</translation>
     </message>
     <message>
         <source>New weapon set</source>
-        <translation type="unfinished"></translation>
+        <translation>Neues Waffenprofil</translation>
     </message>
     <message>
         <source>Edit weapon set</source>
-        <translation type="unfinished"></translation>
+        <translation>Waffenprofil bearbeiten</translation>
     </message>
     <message>
         <source>Delete weapon set</source>
-        <translation type="unfinished"></translation>
+        <translation>Waffenprofil löschen</translation>
     </message>
 </context>
 <context>
@@ -963,6 +1039,13 @@ Do you still want to join the room?</source>
         <translation>Das Spiel in das du beitreten möchtest hat bereits begonnen.
 Willst du trotzdem den Raum betreten?</translation>
     </message>
+    <message numerus="yes">
+        <source>%1 players online</source>
+        <translation>
+            <numerusform>%1 Spieler online</numerusform>
+            <numerusform>%1 Spieler online</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageScheme</name>
@@ -1010,10 +1093,6 @@ Willst du trotzdem den Raum betreten?</translation>
         <source>Land can not be destroyed!</source>
         <translation>Die Landschaft ist nicht zerstörbar!</translation>
     </message>
-    <message>
-        <source>Add an indestructable border around the terrain</source>
-        <translation>Einfügen eines unzerstörbaren Kartenrand</translation>
-    </message>
     <message>
         <source>Lower gravity</source>
         <translation>Verringerte Schwerkraft</translation>
@@ -1072,15 +1151,27 @@ Willst du trotzdem den Raum betreten?</translation>
     </message>
     <message>
         <source>You will not have to worry about wind anymore.</source>
-        <translation type="unfinished"></translation>
+        <translation>Du wirst dich nicht mehr um Wind kümmern müssen.</translation>
     </message>
     <message>
         <source>Wind will affect almost everything.</source>
-        <translation type="unfinished"></translation>
+        <translation>Wind beeinflusst fast alles.</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopieren</translation>
+    </message>
+    <message>
+        <source>Teams in each clan take successive turns sharing their turn time.</source>
+        <translation>Teams gleicher Farbe kommen nacheinander dran und teilen sich ihre Zugzeit.</translation>
+    </message>
+    <message>
+        <source>Add an indestructible border around the terrain</source>
+        <translation>Fügt eine unzerstörbare Randbegrenzung um das Spielfeld herum hinzu.</translation>
+    </message>
+    <message>
+        <source>Add an indestructible border along the bottom</source>
+        <translation>Fügt eine unzerstörbare Randbegrenzung am unteren Kartenrand hinzu.</translation>
     </message>
 </context>
 <context>
@@ -1095,11 +1186,11 @@ Willst du trotzdem den Raum betreten?</translation>
     </message>
     <message>
         <source>New</source>
-        <translation type="unfinished">Neu</translation>
+        <translation>Neu</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopieren</translation>
     </message>
 </context>
 <context>
@@ -1175,6 +1266,10 @@ Willst du trotzdem den Raum betreten?</translation>
         <source>Remove friend</source>
         <translation>Als Freund entfernen</translation>
     </message>
+    <message>
+        <source>Update</source>
+        <translation>Aktualisieren</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -1279,7 +1374,71 @@ Willst du trotzdem den Raum betreten?</translation>
     </message>
     <message>
         <source>hand drawn map...</source>
-        <translation type="unfinished"></translation>
+        <translation>Handgezeichnete Karte</translation>
+    </message>
+    <message>
+        <source>Disabled</source>
+        <translation>Deaktiviert</translation>
+    </message>
+    <message>
+        <source>Red/Cyan</source>
+        <translation>Rot/Türkis</translation>
+    </message>
+    <message>
+        <source>Cyan/Red</source>
+        <translation>Türkis/Rot</translation>
+    </message>
+    <message>
+        <source>Red/Blue</source>
+        <translation>Rot/Blau</translation>
+    </message>
+    <message>
+        <source>Blue/Red</source>
+        <translation>Blau/Rot</translation>
+    </message>
+    <message>
+        <source>Red/Green</source>
+        <translation>Rot/Grün</translation>
+    </message>
+    <message>
+        <source>Green/Red</source>
+        <translation>Grün/Rot</translation>
+    </message>
+    <message>
+        <source>Side-by-side</source>
+        <translation>Nebeneinander</translation>
+    </message>
+    <message>
+        <source>Top-Bottom</source>
+        <translation>Übereinander</translation>
+    </message>
+    <message>
+        <source>Wiggle</source>
+        <translation>Wackeln</translation>
+    </message>
+    <message>
+        <source>Red/Cyan grayscale</source>
+        <translation>Rot/Türkis Graustufen</translation>
+    </message>
+    <message>
+        <source>Cyan/Red grayscale</source>
+        <translation>Türkis/Rot Graustufen</translation>
+    </message>
+    <message>
+        <source>Red/Blue grayscale</source>
+        <translation>Rot/Blau Graustufen</translation>
+    </message>
+    <message>
+        <source>Blue/Red grayscale</source>
+        <translation>Blau/Rot Graustufen</translation>
+    </message>
+    <message>
+        <source>Red/Green grayscale</source>
+        <translation>Rot/Grün Graustufen</translation>
+    </message>
+    <message>
+        <source>Green/Red grayscale</source>
+        <translation>Grün/Rot Graustufen</translation>
     </message>
 </context>
 <context>
@@ -1334,7 +1493,7 @@ Willst du trotzdem den Raum betreten?</translation>
     </message>
     <message>
         <source>Schemes and Weapons</source>
-        <translation type="unfinished"></translation>
+        <translation>Spielprofile und Waffen</translation>
     </message>
 </context>
 <context>
@@ -1511,11 +1670,31 @@ Einige Dinge könnten nicht funktionieren oder unvollständig sein. Benutzung au
     </message>
     <message>
         <source>% Rope Length</source>
-        <translation type="unfinished"></translation>
+        <translation>% Seillänge</translation>
     </message>
     <message>
-        <source>Gameplay</source>
-        <translation type="unfinished"></translation>
+        <source>Stereo rendering</source>
+        <translation>Stereo-Rendering</translation>
+    </message>
+    <message>
+        <source>Game Options</source>
+        <translation>Spieloptionen</translation>
+    </message>
+    <message>
+        <source>Style</source>
+        <translation>Stil</translation>
+    </message>
+    <message>
+        <source>Scheme</source>
+        <translation>Spielprofil</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Passwort</translation>
+    </message>
+    <message>
+        <source>% Get Away Time</source>
+        <translation>% Rückzugszeit</translation>
     </message>
 </context>
 <context>
@@ -1524,6 +1703,10 @@ Einige Dinge könnten nicht funktionieren oder unvollständig sein. Benutzung au
         <source>unnamed</source>
         <translation>unbenannt</translation>
     </message>
+    <message>
+        <source>hedgehog %1</source>
+        <translation>Igel %1</translation>
+    </message>
 </context>
 <context>
     <name>QMainWindow</name>
@@ -1584,27 +1767,27 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
     </message>
     <message>
         <source>Teams</source>
-        <translation type="unfinished">Teams</translation>
+        <translation>Teams</translation>
     </message>
     <message>
         <source>Really delete this team?</source>
-        <translation type="unfinished"></translation>
+        <translation>Dieses Team wirklich löschen?</translation>
     </message>
     <message>
         <source>Schemes</source>
-        <translation type="unfinished"></translation>
+        <translation>Spielprofil</translation>
     </message>
     <message>
         <source>Can not delete default scheme &apos;%1&apos;!</source>
-        <translation type="unfinished"></translation>
+        <translation>Standardspielprofil &apos;%1&apos; kann nicht gelöscht werden!</translation>
     </message>
     <message>
         <source>Really delete this game scheme?</source>
-        <translation type="unfinished"></translation>
+        <translation>Dieses Spielprofil wirklich löschen?</translation>
     </message>
     <message>
         <source>Can not delete default weapon set &apos;%1&apos;!</source>
-        <translation type="unfinished"></translation>
+        <translation>Standardwaffenprofil &apos;%1&apos; kann nicht gelöscht werden!</translation>
     </message>
 </context>
 <context>
@@ -1702,7 +1885,7 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
     </message>
     <message>
         <source>more</source>
-        <translation type="unfinished"></translation>
+        <translation>mehr</translation>
     </message>
 </context>
 <context>
@@ -1756,11 +1939,11 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
     </message>
     <message>
         <source>new</source>
-        <translation type="unfinished">Neu</translation>
+        <translation>neu</translation>
     </message>
     <message>
         <source>copy of</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopie von</translation>
     </message>
 </context>
 <context>
@@ -1870,11 +2053,19 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
     </message>
     <message>
         <source>Disable Wind</source>
-        <translation type="unfinished"></translation>
+        <translation>Kein Wind</translation>
     </message>
     <message>
         <source>More Wind</source>
-        <translation type="unfinished"></translation>
+        <translation>Mehr Wind</translation>
+    </message>
+    <message>
+        <source>Tag Team</source>
+        <translation>Tag Team</translation>
+    </message>
+    <message>
+        <source>Add Bottom Border</source>
+        <translation>Untere Randbegrenzung hinzufügen</translation>
     </message>
 </context>
 <context>
