@@ -12,6 +12,21 @@
         <translation>kopia av</translation>
     </message>
 </context>
+<context>
+    <name>DrawMapWidget</name>
+    <message>
+        <source>File error</source>
+        <translation>Fel på fil</translation>
+    </message>
+    <message>
+        <source>Cannot open file &apos;%1&apos; for writing</source>
+        <translation>Kan inte skriva till &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <source>Cannot read file &apos;%1&apos;</source>
+        <translation>Kan inte läsa &apos;%1&apos;</translation>
+    </message>
+</context>
 <context>
     <name>FreqSpinBox</name>
     <message>
@@ -108,6 +123,14 @@
         <comment>File Types</comment>
         <translation>Sparfil för Hedgewars</translation>
     </message>
+    <message>
+        <source>Demo name</source>
+        <translation>Demonamn</translation>
+    </message>
+    <message>
+        <source>Demo name:</source>
+        <translation>Demonamn:</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
@@ -192,7 +215,7 @@
     </message>
     <message>
         <source>Set</source>
-        <translation type="unfinished">Ange</translation>
+        <translation>Ange</translation>
     </message>
 </context>
 <context>
@@ -272,6 +295,20 @@ registrerat på Hedgewars.org
 Var god ange ditt lösenord eller välj
 ett annat smeknamn i spelinställningarna:</translation>
     </message>
+    <message>
+        <source>Nickname</source>
+        <translation>Smeknamn</translation>
+    </message>
+    <message>
+        <source>Some one already uses
+ your nickname %1
+on the server.
+Please pick another nickname:</source>
+        <translation>Någon använder redan
+ditt smeknamn %1
+på servern.
+Välj ett annat smeknamn:</translation>
+    </message>
 </context>
 <context>
     <name>KB</name>
@@ -325,6 +362,10 @@ ett annat smeknamn i spelinställningarna:</translation>
         <source>Connecting...</source>
         <translation>Ansluter...</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
 </context>
 <context>
     <name>PageDrawMap</name>
@@ -350,12 +391,20 @@ ett annat smeknamn i spelinställningarna:</translation>
     </message>
     <message>
         <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
-        <translation>Ritade kartor (*.hwmap);;Alla filer (*.*)</translation>
+        <translation type="obsolete">Ritade kartor (*.hwmap);;Alla filer (*.*)</translation>
     </message>
     <message>
         <source>Save drawn map</source>
         <translation>Spara ritad karta</translation>
     </message>
+    <message>
+        <source>Drawn Maps</source>
+        <translation>Ritade kartor</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>Alla filer</translation>
+    </message>
 </context>
 <context>
     <name>PageEditTeam</name>
@@ -559,7 +608,7 @@ ett annat smeknamn i spelinställningarna:</translation>
     <message>
         <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
         <comment>Tips</comment>
-        <translation>Windows-versionen av Hedgewars har stöd för Xfire. Se till att lägga till Hedgewars till spellistan så att dina vänner kan se dig spela.</translation>
+        <translation type="obsolete">Windows-versionen av Hedgewars har stöd för Xfire. Se till att lägga till Hedgewars till spellistan så att dina vänner kan se dig spela.</translation>
     </message>
     <message>
         <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
@@ -629,7 +678,7 @@ ett annat smeknamn i spelinställningarna:</translation>
     <message>
         <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
         <comment>Tips</comment>
-        <translation>Målsökande biet kan vara svårt att använda. Biets sväng beror på hastigheten, så försök inte att använda full kraft.</translation>
+        <translation type="obsolete">Målsökande biet kan vara svårt att använda. Biets sväng beror på hastigheten, så försök inte att använda full kraft.</translation>
     </message>
     <message>
         <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
@@ -659,7 +708,7 @@ ett annat smeknamn i spelinställningarna:</translation>
     <message>
         <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
         <comment>Tips</comment>
-        <translation>Använd Molotov för att tillfälligt förhindra igelkottar från att passera terräng såsom tunnlar och platformer.</translation>
+        <translation type="obsolete">Använd Molotov för att tillfälligt förhindra igelkottar från att passera terräng såsom tunnlar och platformer.</translation>
     </message>
     <message>
         <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
@@ -716,6 +765,25 @@ ett annat smeknamn i spelinställningarna:</translation>
         <comment>Tips</comment>
         <translation>Du kan hitta dina konfigurationsfiler under &quot;.hedgewars&quot; i din hem-mapp. Gör en säkerhetskopia eller ta med dig filerna, men redigera dem inte för hand.</translation>
     </message>
+    <message>
+        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgewars to its game list so your friends can see you playing.</source>
+        <comment>Tips</comment>
+        <translation>Windows-versionen av Hedgewars har stöd för Xfire. Se till att lägga till Hedgewars till spellistan så att dina vänner kan se dig spela.</translation>
+    </message>
+    <message>
+        <source>Use the Molotov or Flame Thrower to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
+        <comment>Tips</comment>
+        <translation>Använd molotov eller eldkastaren för att temporärt förhindra att igelkottar passerar terräng så som tunnlar eller platformar.</translation>
+    </message>
+    <message>
+        <source>The Homing Bee can be tricky to use. Its turn radius depends on its velocity, so try to not use full power.</source>
+        <comment>Tips</comment>
+        <translation>Målsökande bin kan vara kluriga att använda. Svängradien beror på hastigheten, så försök att inte använda full kraft.</translation>
+    </message>
+    <message>
+        <source>Downloadable Content</source>
+        <translation>Nedladdningsbart innehåll</translation>
+    </message>
 </context>
 <context>
     <name>PageMultiplayer</name>
@@ -741,6 +809,18 @@ ett annat smeknamn i spelinställningarna:</translation>
         <source>Control</source>
         <translation>Kontroll</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Fel</translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Skriv in rummets namn</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
 </context>
 <context>
     <name>PageNetType</name>
@@ -957,6 +1037,13 @@ Do you still want to join the room?</source>
         <translation>Spelet du försöker gå med i har startat.
 Vill du fortfarande gå med i rummet?</translation>
     </message>
+    <message numerus="yes">
+        <source>%1 players online</source>
+        <translation>
+            <numerusform>%1 spelare inne</numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageScheme</name>
@@ -1006,7 +1093,7 @@ Vill du fortfarande gå med i rummet?</translation>
     </message>
     <message>
         <source>Add an indestructable border around the terrain</source>
-        <translation>Lägger till en oförstörbar kant runt terrängen</translation>
+        <translation type="obsolete">Lägger till en oförstörbar kant runt terrängen</translation>
     </message>
     <message>
         <source>Lower gravity</source>
@@ -1076,6 +1163,18 @@ Vill du fortfarande gå med i rummet?</translation>
         <source>Copy</source>
         <translation>Kopiera</translation>
     </message>
+    <message>
+        <source>Teams in each clan take successive turns sharing their turn time.</source>
+        <translation>Lag inom en klan spelar efter varandra och delar på turtiden.</translation>
+    </message>
+    <message>
+        <source>Add an indestructible border around the terrain</source>
+        <translation>Lägger till en oförstörbar kant runt terrängen</translation>
+    </message>
+    <message>
+        <source>Add an indestructible border along the bottom</source>
+        <translation>Lägg till en oförstörbar barriär längs botten</translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -1169,6 +1268,10 @@ Vill du fortfarande gå med i rummet?</translation>
         <source>Remove friend</source>
         <translation>Ta bort som vän</translation>
     </message>
+    <message>
+        <source>Update</source>
+        <translation>Uppdatera</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -1307,6 +1410,70 @@ Vill du fortfarande gå med i rummet?</translation>
         <source>hand drawn map...</source>
         <translation>handritad karta...</translation>
     </message>
+    <message>
+        <source>Disabled</source>
+        <translation>Avaktiverad</translation>
+    </message>
+    <message>
+        <source>Red/Cyan</source>
+        <translation>Röd/Cyan</translation>
+    </message>
+    <message>
+        <source>Cyan/Red</source>
+        <translation>Cyan/Röd</translation>
+    </message>
+    <message>
+        <source>Red/Blue</source>
+        <translation>Röd/Blå</translation>
+    </message>
+    <message>
+        <source>Blue/Red</source>
+        <translation>Blå/Röd</translation>
+    </message>
+    <message>
+        <source>Red/Green</source>
+        <translation>Röd/Grön</translation>
+    </message>
+    <message>
+        <source>Green/Red</source>
+        <translation>Grön/Röd</translation>
+    </message>
+    <message>
+        <source>Side-by-side</source>
+        <translation>Sida vid sida</translation>
+    </message>
+    <message>
+        <source>Top-Bottom</source>
+        <translation>Uppe och nere</translation>
+    </message>
+    <message>
+        <source>Wiggle</source>
+        <translation>Vicka</translation>
+    </message>
+    <message>
+        <source>Red/Cyan grayscale</source>
+        <translation>Röd/Cyan gråskala</translation>
+    </message>
+    <message>
+        <source>Cyan/Red grayscale</source>
+        <translation>Cyan/Röd gråskala</translation>
+    </message>
+    <message>
+        <source>Red/Blue grayscale</source>
+        <translation>Röd/Blå gråskala</translation>
+    </message>
+    <message>
+        <source>Blue/Red grayscale</source>
+        <translation>Blå/Röd gråskala</translation>
+    </message>
+    <message>
+        <source>Red/Green grayscale</source>
+        <translation>Röd/Grön gråskala</translation>
+    </message>
+    <message>
+        <source>Green/Red grayscale</source>
+        <translation>Grön/Röd gråskala</translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
@@ -1541,7 +1708,31 @@ Det kan finnas trasiga eller ofullständiga funktioner. Använd på egen risk!</
     </message>
     <message>
         <source>Gameplay</source>
-        <translation>Speltyp</translation>
+        <translation type="obsolete">Speltyp</translation>
+    </message>
+    <message>
+        <source>Stereo rendering</source>
+        <translation>Stereorendering</translation>
+    </message>
+    <message>
+        <source>Game Options</source>
+        <translation>Spelinställningar</translation>
+    </message>
+    <message>
+        <source>Style</source>
+        <translation>Stil</translation>
+    </message>
+    <message>
+        <source>Scheme</source>
+        <translation>Schema</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Lösenord</translation>
+    </message>
+    <message>
+        <source>% Get Away Time</source>
+        <translation>% flykttid</translation>
     </message>
 </context>
 <context>
@@ -1550,6 +1741,10 @@ Det kan finnas trasiga eller ofullständiga funktioner. Använd på egen risk!</
         <source>unnamed</source>
         <translation>onämnd</translation>
     </message>
+    <message>
+        <source>hedgehog %1</source>
+        <translation>igelkott %1</translation>
+    </message>
 </context>
 <context>
     <name>QMainWindow</name>
@@ -1732,7 +1927,7 @@ Var god kontrollera din installation</translation>
     </message>
     <message>
         <source>more</source>
-        <translation type="unfinished"></translation>
+        <translation>mer</translation>
     </message>
 </context>
 <context>
@@ -1906,6 +2101,14 @@ Var god kontrollera din installation</translation>
         <source>More Wind</source>
         <translation>Mer vind</translation>
     </message>
+    <message>
+        <source>Tag Team</source>
+        <translation>Maraton</translation>
+    </message>
+    <message>
+        <source>Add Bottom Border</source>
+        <translation>Lägg till undre barriär</translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
